@@ -1,6 +1,6 @@
 
-import aiohttp
 import logging
+import asyncio
 from typing import List
 
 from orionx_python_client import OrionXClient
@@ -25,12 +25,13 @@ class OrionXExchange(ExchangeService):
         self, order_id: str, market_code: str
     ):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.get_order(order_id=order_id, session=session)
-                order = self.order_parser.parse_response(
-                    order_id=order_id,
-                    market_code=market_code,
-                    response=response)
+
+            response = self.client.get_order(
+                order_id=order_id)
+            order = self.order_parser.parse_response(
+                order_id=order_id,
+                market_code=market_code,
+                response=response)
             return order
         except Exception as err:
             logging.error(err)
@@ -38,10 +39,11 @@ class OrionXExchange(ExchangeService):
 
     async def get_transaction_from_order_response(self, order_id: str) -> Order:
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.get_order(order_id=order_id,  session=session)
-                order = self.transaction_from_order_parser.parse_response(
-                    response=response)
+
+            response = self.client.get_order(
+                order_id=order_id)
+            order = self.transaction_from_order_parser.parse_response(
+                response=response)
             return order
         except Exception as err:
             logging.debug(err)
@@ -49,10 +51,10 @@ class OrionXExchange(ExchangeService):
 
     async def get_wallet_response(self, currency_ceros: dict = ORIONX_CEROS):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.get_balance(session=session)
-                wallet = self.wallet_parser.parse_response(
-                    response=response, currency_ceros=currency_ceros)
+
+            response = self.client.get_balance()
+            wallet = self.wallet_parser.parse_response(
+                response=response, currency_ceros=currency_ceros)
             return wallet
         except Exception as err:
             logging.error(err)
@@ -60,8 +62,8 @@ class OrionXExchange(ExchangeService):
 
     async def get_open_orders(self):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.get_open_orders(session=session)
+
+            response = self.client.get_open_orders()
             logging.info(response)
             return response
         except Exception as err:
@@ -70,8 +72,9 @@ class OrionXExchange(ExchangeService):
 
     async def get_open_orders_by_market(self, market: str, selling: str):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.get_open_orders_by_market(market=market, selling=selling, session=session)
+
+            response = self.client.get_open_orders_by_market(
+                market=market, selling=selling)
             logging.info(response)
             return response
         except Exception as err:
@@ -80,8 +83,9 @@ class OrionXExchange(ExchangeService):
 
     async def close_orders(self, order_ids: List[str]):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.close_orders(order_ids=order_ids, session=session)
+
+            response = self.client.close_orders(
+                order_ids=order_ids)
             logging.info(response)
             return response
         except Exception as err:
@@ -90,8 +94,9 @@ class OrionXExchange(ExchangeService):
 
     async def close_orders_by_market(self, market: str, selling: str):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.close_orders_by_market(market=market, selling=selling, session=session)
+
+            response = self.client.close_orders_by_market(
+                market=market, selling=selling)
             logging.info(response)
             return response
         except Exception as err:
@@ -100,8 +105,9 @@ class OrionXExchange(ExchangeService):
 
     async def get_order_status(self, order_id: str):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.get_order_status(order_id=order_id, session=session)
+
+            response = self.client.get_order_status(
+                order_id=order_id)
             logging.info(response)
             return response
         except Exception as err:
@@ -110,8 +116,8 @@ class OrionXExchange(ExchangeService):
 
     async def close_order_by_id(self, order_id: str):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.close_order_by_id(order_id=order_id, session=session)
+
+            response = self.client.close_order_by_id(order_id=order_id)
             logging.info(response)
 
             return response
@@ -128,9 +134,10 @@ class OrionXExchange(ExchangeService):
         selling: str,
     ):
         try:
-            async with aiohttp.ClientSession() as session:
-                response = await self.client.new_position(market_code=market_code, amount=amount, limit_price=limit_price, selling=selling, session=session)
-                logging.info(response)
+
+            response = self.client.new_position(
+                market_code=market_code, amount=amount, limit_price=limit_price, selling=selling)
+            logging.info(response)
             return response
         except Exception as err:
             logging.debug(err)
